==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebOverlayOutletDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebOverlayOutletDirectiveDescription } from "./WebOverlayOutletDirectiveDescription";
/**
 * @hidden
 */
export let WebOverlayOutletDirectiveDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebOverlayOutletDirectiveDescriptionMetadata extends Base {
        static b(a) {
            if (WebOverlayOutletDirectiveDescriptionMetadata.a == null) {
                WebOverlayOutletDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebOverlayOutletDirectiveDescriptionMetadata.c(WebOverlayOutletDirectiveDescriptionMetadata.a);
            }
            if (a.k(WebOverlayOutletDirectiveDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebOverlayOutletDirectiveDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:OverlayOutletDirective");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebOverlayOutletDirectiveDescriptionMetadata.b(a);
            a.ad("WebOverlayOutletDirective", () => new WebOverlayOutletDirectiveDescription());
            a.ac("WebOverlayOutletDirective", WebOverlayOutletDirectiveDescriptionMetadata.a);
        }
    }
    WebOverlayOutletDirectiveDescriptionMetadata.$t = /*@__PURE__*/ markType(WebOverlayOutletDirectiveDescriptionMetadata, 'WebOverlayOutletDirectiveDescriptionMetadata');
    WebOverlayOutletDirectiveDescriptionMetadata.a = null;
    return WebOverlayOutletDirectiveDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebOverlayOutletDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebOverlayOutletDirectiveDescription } from "./WebOverlayOutletDirectiveDescription";
/**
 * @hidden
 */
export let WebOverlayOutletDirectiveDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebOverlayOutletDirectiveDescriptionMetadata extends Base {
        static b(a) {
            if (WebOverlayOutletDirectiveDescriptionMetadata.a == null) {
                WebOverlayOutletDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebOverlayOutletDirectiveDescriptionMetadata.c(WebOverlayOutletDirectiveDescriptionMetadata.a);
            }
            if (a.k(WebOverlayOutletDirectiveDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebOverlayOutletDirectiveDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:OverlayOutletDirective");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebOverlayOutletDirectiveDescriptionMetadata.b(a);
            a.ae("WebOverlayOutletDirective", () => new WebOverlayOutletDirectiveDescription());
            a.ad("WebOverlayOutletDirective", WebOverlayOutletDirectiveDescriptionMetadata.a);
        }
    }
    WebOverlayOutletDirectiveDescriptionMetadata.$t = /*@__PURE__*/ markType(WebOverlayOutletDirectiveDescriptionMetadata, 'WebOverlayOutletDirectiveDescriptionMetadata');
    WebOverlayOutletDirectiveDescriptionMetadata.a = null;
    return WebOverlayOutletDirectiveDescriptionMetadata;
})();
